<?php

namespace DsbNext\Util;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class Util{
    const TABLE_LISTA = "LISTA";
    
    public function __construct($connection, $crudService, $environment, $dataSourceManager, $newCode) {
        $this->crudService = $crudService;
        $this->environment = $environment;
        $this->connection  = $connection;
        $this->dataSourceManager = $dataSourceManager;
        $this->newCode = $newCode;
    }
    
    public function getSessionData() {
        $sessionData = array(
            "NRORG" => $this->environment->getNrorg(),
            "CDOPERADOR" => $this->environment->getCdOperador(),
            "CDFILIAL" => $this->environment->getCdFilial(),
            "CDFILCENTCMP" => $this->getCentralCompras()
        );
        return $sessionData;
    }
    
    public function getDateProc () {
        $params = array (
            'P_CDFILIAL' => $this->environment->getCdFilial()
        );
        $query = "SELECT CASE WHEN NVL(G.IDUTILDTPROC,'N') = 'S' 
                              THEN TRUNC(NVL(P.DTPROCESSA,SYSDATE)) 
                              ELSE TRUNC(SYSDATE) 
                         END DTPROCESSA 
                    FROM PARAMFILIAL P, PARAMGERAL G
                   WHERE P.CDFILIAL = :P_CDFILIAL
                     AND G.CDPARGERAL = '0001'
                     AND P.NRORG = G.NRORG";
        $std = $this->connection->prepare($query);
        $std->execute($params);
        $result= $std->fetchAll()[0];
        $dataProc = substr($result["DTPROCESSA"], 0, 10);
        return $dataProc;
    }
    
    public function prepareConditions($params) {
         $sessionData = $this->getSessionData();
         $sessionData['DTPROCESSA'] = $dataProc = $this->getDateProc();
         $conditions = [];
         foreach($params as $param){
             array_push($conditions, array(
                "columnName" => $param,
                "operator"   => '=',
                "value"      => $sessionData[$param]
            ));
        }
        return $conditions;
    }
    
    public function insertLista($cdlistaArray) {
        if(gettype($cdlistaArray) == 'string'){
            $cdlistaArray = [$cdlistaArray];
        }
        $dataSourceName = strtolower(self::TABLE_LISTA);
        $nrlista = $this->newCode->getCodeByTableName(self::TABLE_LISTA, $this->environment->getNrOrg());
        $sql = "INSERT INTO " . self::TABLE_LISTA . " (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        
        foreach ($cdlistaArray as $cdlista) {
            $params = array(
                "NRLISTA" => $nrlista,
                "CDLISTA" => $cdlista
            );
            $query = $this->connection->prepare($sql);
            $query->execute($params);
        }
        return $nrlista;
    }
    
    public function deleteLista($nrlista) {
        $dataSourceName = strtolower(self::TABLE_LISTA);
        $conditions = array(
            array(
                "columnName" => "NRLISTA",
                "operator"   => '=',
                "value"      => $nrlista
            )
        );
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);
        $this->dataSourceManager->delete($dataSet);
    }
    
    public function getCentralCompras($codigoFilial = null) {
        if (!$codigoFilial) {
            $codigoFilial = $this->environment->getCdFilial();
        }
        
        $query = "SELECT F2.CDFILIAL AS CDFILCENTCMP
                    FROM FILIAL F, FILIAL F2
                   WHERE F.CDFILIAL = :CDFILIAL
                     AND F2.CDFILIAL = NVL(F.CDFILCENTCMP, F.CDFILIAL)";
        $std = $this->connection->prepare($query);
        
        $std->execute(array(
            "CDFILIAL" => $codigoFilial
        ));
        
        return $std->fetch()["CDFILCENTCMP"];
    }
} 